<div class="places-widget" data-map-options="{{ map_options }}" data-marker-options="{{ marker_options }}">
	{% include 'django/forms/widgets/multiwidget.html' %}
  	<div id="map_location" style="height:{{ map_widget_height }}px; width: 100%"></div>
</div>
