#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj-places
------------

Tests for `dj-places` models module.
"""

from django.test import TestCase

from djplaces.fields import LocationField


class TestDjplaces(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
